@@ -1,7 +1,7 @@
 package App::shcompgen;
 
-our $DATE = '2016-11-03'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2016-12-03'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -615,7 +615,7 @@ sub _detect_prog {
                 if ($line =~ /^\s*((?:use|require)\s+
                                   (
                                       Getopt::Std|
-                                      Getopt::Long(?:::Complete|::Subcommand|::Descriptive)?|
+                                      Getopt::Long(?:::Complete|::Subcommand|::More|::Descriptive)?|
                                       Perinci::CmdLine(?:::Any|::Lite|::Classic)
                               ))\b/x) {
                     return [200, "OK", 1, {
@@ -1142,7 +1142,7 @@ App::shcompgen - Generate shell completion scripts
 
 =head1 VERSION
 
-This document describes version 0.29 of App::shcompgen (from Perl distribution App-shcompgen), released on 2016-11-03.
+This document describes version 0.30 of App::shcompgen (from Perl distribution App-shcompgen), released on 2016-12-03.
 
 =head1 FUNCTIONS
 
